#
# spec file for package selinux-policy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# There are almost no SUSE specific modifications available in the policy, so we utilize the
# ones used by redhat and include also the SUSE specific ones (see sed statement below)
%define distro redhat
%define ubac n
%define polyinstatiate n
%define monolithic n
%define BUILD_TARGETED 1
%define BUILD_MINIMUM 1
%define BUILD_MLS 1

%define POLICYCOREUTILSVER %(rpm -q --qf %%{version} policycoreutils)
%define CHECKPOLICYVER %POLICYCOREUTILSVER

Summary:        SELinux policy configuration
License:        GPL-2.0-or-later
Group:          System/Management
Name:           selinux-policy
Version:        20210716
Release:        150300.13.8.1
Source:         fedora-policy-%{version}.tar.bz2
Source1:        selinux-policy-rpmlintrc

Source10:       modules-targeted-base.conf
Source11:       modules-targeted-contrib.conf
Source12:       modules-mls-base.conf
Source13:       modules-mls-contrib.conf
Source14:       modules-minimum-base.conf
Source15:       modules-minimum-contrib.conf
Source18:       modules-minimum-disable.lst

Source20:       booleans-targeted.conf
Source21:       booleans-mls.conf
Source22:       booleans-minimum.conf
Source23:       booleans.subs_dist

Source30:       setrans-targeted.conf
Source31:       setrans-mls.conf
Source32:       setrans-minimum.conf

Source40:       securetty_types-targeted
Source41:       securetty_types-mls
Source42:       securetty_types-minimum

Source50:       users-targeted
Source51:       users-mls
Source52:       users-minimum

Source60:       selinux-policy.conf

Source91:       Makefile.devel
Source92:       customizable_types
#Source93:       config.tgz
Source94:       file_contexts.subs_dist
Source95:       macros.selinux-policy
Source96:       update.sh

Source120:      packagekit.te
Source121:      packagekit.if
Source122:      packagekit.fc
Source123:      rtorrent.te
Source124:      rtorrent.if
Source125:      rtorrent.fc
Source126:      wicked.te
Source127:      wicked.if
Source128:      wicked.fc
Source129:      rebootmgr.te
Source130:      rebootmgr.if
Source131:      rebootmgr.fc

Patch001:       fix_djbdns.patch
Patch002:       fix_dbus.patch
Patch004:       fix_java.patch
Patch005:       fix_hadoop.patch
Patch006:       fix_thunderbird.patch
Patch007:       fix_postfix.patch
Patch008:       fix_nscd.patch
Patch009:       fix_sysnetwork.patch
Patch010:       fix_logging.patch
Patch011:       fix_xserver.patch
Patch012:       fix_miscfiles.patch
Patch013:       fix_init.patch
Patch014:       fix_locallogin.patch
Patch016:       fix_iptables.patch
Patch017:       fix_irqbalance.patch
Patch018:       fix_ntp.patch
Patch019:       fix_fwupd.patch
Patch020:       fix_firewalld.patch
Patch021:       fix_logrotate.patch
Patch022:       fix_selinuxutil.patch
Patch024:       fix_corecommand.patch
Patch025:       fix_snapper.patch
Patch026:       fix_systemd.patch
Patch027:       fix_unconfined.patch
Patch028:       fix_unconfineduser.patch
Patch029:       fix_chronyd.patch
Patch030:       fix_networkmanager.patch
Patch032:       fix_accountsd.patch
Patch033:       fix_automount.patch
Patch034:       fix_colord.patch
Patch035:       fix_mcelog.patch
Patch036:       fix_sslh.patch
Patch037:       fix_nagios.patch
Patch038:       fix_openvpn.patch
Patch039:       fix_cron.patch
Patch040:       fix_usermanage.patch
Patch041:       fix_smartmon.patch
Patch042:       fix_geoclue.patch
Patch044:       fix_authlogin.patch
Patch045:       fix_screen.patch
Patch046:       fix_unprivuser.patch
Patch047:       fix_rpm.patch
Patch048:       fix_apache.patch
Patch049:       fix_nis.patch
Patch050:       fix_libraries.patch
Patch051:       fix_dovecot.patch
# https://github.com/cockpit-project/cockpit/pull/15758
Patch052:       fix_cockpit.patch
Patch053:       fix_systemd_watch.patch
# kernel specific sysctl.conf (boo#1184804)
Patch054:       fix_kernel_sysctl.patch
Patch055:       fix_auditd.patch
Patch056:       fix_hypervkvp.patch
Patch057:       systemd_domain_dyntrans_type.patch
Patch058:       fix_cloudform.patch

Patch100:       sedoctool.patch
# bsc#1187313
Patch101:       init_watch_unallocated_ttys.patch

URL:            https://github.com/fedora-selinux/selinux-policy.git
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  checkpolicy
BuildRequires:  gawk
BuildRequires:  libxml2-tools
BuildRequires:  m4
BuildRequires:  policycoreutils
BuildRequires:  policycoreutils-devel
BuildRequires:  python3
BuildRequires:  python3-policycoreutils
# we need selinuxenabled
Requires(pre):  policycoreutils >= %{POLICYCOREUTILSVER}
Requires(pre):  pam-config
Requires(post): pam-config
Requires(post): selinux-tools
Requires(post): /usr/bin/sha512sum
Recommends:     audit
Recommends:     selinux-tools
# for audit2allow
Recommends:     python3-policycoreutils
Recommends:     container-selinux
Recommends:     policycoreutils-python-utils
Recommends:     selinux-autorelabel

%define common_params DISTRO=%{distro} UBAC=%{ubac} DIRECT_INITRC=n MONOLITHIC=%{monolithic} MLS_CATS=1024 MCS_CATS=1024

%define makeCmds() \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 bare \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 conf \
cp -f selinux_config/booleans-%1.conf ./policy/booleans.conf \
cp -f selinux_config/users-%1 ./policy/users \
#cp -f selinux_config/modules-%1-base.conf  ./policy/modules.conf \

%define makeModulesConf() \
cp -f selinux_config/modules-%1-%2.conf  ./policy/modules-base.conf \
cp -f selinux_config/modules-%1-%2.conf  ./policy/modules.conf \
if [ %3 == "contrib" ];then \
        cp selinux_config/modules-%1-%3.conf ./policy/modules-contrib.conf; \
        cat selinux_config/modules-%1-%3.conf >> ./policy/modules.conf; \
fi; \

%define installCmds() \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 base.pp \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 validate modules \
make %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 DESTDIR=%{buildroot} install \
make %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 DESTDIR=%{buildroot} install-appconfig \
make %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 DESTDIR=%{buildroot} SEMODULE="%{_sbindir}/semodule -p %{buildroot} -X 100 " load \
%{__mkdir} -p %{buildroot}%{_sysconfdir}/selinux/%1/logins \
%{__mkdir} -p %{buildroot}%{_sharedstatedir}/selinux/%1/active/modules/{1,2,4}00 \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.subs \
install -m0644 selinux_config/securetty_types-%1 %{buildroot}%{_sysconfdir}/selinux/%1/contexts/securetty_types \
install -m0644 selinux_config/file_contexts.subs_dist %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files \
install -m0644 selinux_config/setrans-%1.conf %{buildroot}%{_sysconfdir}/selinux/%1/setrans.conf \
install -m0644 selinux_config/customizable_types %{buildroot}%{_sysconfdir}/selinux/%1/contexts/customizable_types \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.bin \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local.bin \
cp %{SOURCE23} %{buildroot}%{_sysconfdir}/selinux/%1 \
rm -f %{buildroot}%{_datadir}/selinux/%1/*pp*  \
%{_bindir}/sha512sum %{buildroot}%{_sysconfdir}/selinux/%1/policy/policy.* | cut -d' ' -f 1 > %{buildroot}%{_sysconfdir}/selinux/%1/.policy.sha512; \
rm -rf %{buildroot}%{_sysconfdir}/selinux/%1/contexts/netfilter_contexts  \
rm -rf %{buildroot}%{_sysconfdir}/selinux/%1/modules/active/policy.kern \
rm -f %{buildroot}%{_sharedstatedir}/selinux/%1/active/*.linked \
%nil

%define fileList() \
%defattr(-,root,root) \
%dir %{_sysconfdir}/selinux/%1 \
%config(noreplace) %{_sysconfdir}/selinux/%1/setrans.conf \
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/seusers \
%dir %{_sysconfdir}/selinux/%1/logins \
%dir %{_sharedstatedir}/selinux/%1/active \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/semanage.read.LOCK \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/semanage.trans.LOCK \
%dir %attr(700,root,root) %{_sharedstatedir}/selinux/%1/active/modules \
%dir %{_sharedstatedir}/selinux/%1/active/modules/100 \
%dir %{_sharedstatedir}/selinux/%1/active/modules/200 \
%dir %{_sharedstatedir}/selinux/%1/active/modules/400 \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/active/modules/100/base \
%dir %{_sysconfdir}/selinux/%1/policy/ \
%verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/policy/policy.* \
%{_sysconfdir}/selinux/%1/.policy.sha512 \
%dir %{_sysconfdir}/selinux/%1/contexts \
%config %{_sysconfdir}/selinux/%1/contexts/customizable_types \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/securetty_types \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/dbus_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/x_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/default_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/virtual_domain_context \
%config %{_sysconfdir}/selinux/%1/contexts/virtual_image_context \
%config %{_sysconfdir}/selinux/%1/contexts/lxc_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/systemd_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/sepgsql_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/openssh_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/snapperd_contexts \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/default_type \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/failsafe_context \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/initrc_context \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/removable_context \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/userhelper_context \
%dir %{_sysconfdir}/selinux/%1/contexts/files \
%verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts \
%ghost %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.bin \
%verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.homedirs \
%ghost %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.homedirs.bin \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local \
%ghost %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local.bin \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.subs \
%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.subs_dist \
%{_sysconfdir}/selinux/%1/booleans.subs_dist \
%config %{_sysconfdir}/selinux/%1/contexts/files/media \
%dir %{_sysconfdir}/selinux/%1/contexts/users \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/root \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/guest_u \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/xguest_u \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/user_u \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/staff_u \
%dir %{_datadir}/selinux/%1 \
%dir %{_datadir}/selinux/packages/%1 \
%{_datadir}/selinux/%1/base.lst \
%{_datadir}/selinux/%1/modules-base.lst \
%{_datadir}/selinux/%1/modules-contrib.lst \
%{_datadir}/selinux/%1/nonbasemodules.lst \
%dir %{_sharedstatedir}/selinux/%1 \
%{_sharedstatedir}/selinux/%1/active/commit_num \
%{_sharedstatedir}/selinux/%1/active/users_extra \
%{_sharedstatedir}/selinux/%1/active/homedir_template \
%{_sharedstatedir}/selinux/%1/active/seusers \
%{_sharedstatedir}/selinux/%1/active/file_contexts \
%{_sharedstatedir}/selinux/%1/active/policy.kern \
%ghost %{_sharedstatedir}/selinux/%1/active/policy.linked \
%ghost %{_sharedstatedir}/selinux/%1/active/seusers.linked \
%ghost %{_sharedstatedir}/selinux/%1/active/users_extra.linked \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/active/file_contexts.homedirs \
%nil

%define relabel() \
. %{_sysconfdir}/selinux/config; \
FILE_CONTEXT=%{_sysconfdir}/selinux/%1/contexts/files/file_contexts; \
if selinuxenabled; then \
  if [ $? = 0  -a "${SELINUXTYPE}" = %1 -a -f ${FILE_CONTEXT}.pre ]; then \
    %{_sbindir}/fixfiles -C ${FILE_CONTEXT}.pre restore 2> /dev/null; \
    rm -f ${FILE_CONTEXT}.pre; \
  fi; \
  if /sbin/restorecon -e /run/media -R /root /var/log /var/run %{_sysconfdir}/passwd* %{_sysconfdir}/group* %{_sysconfdir}/*shadow* 2> /dev/null;then \
    continue; \
  fi; \
fi;

%define preInstall() \
if [ $1 -ne 1 ] && [ -s %{_sysconfdir}/selinux/config ]; then \
     . %{_sysconfdir}/selinux/config; \
     FILE_CONTEXT=%{_sysconfdir}/selinux/%1/contexts/files/file_contexts; \
     if [ "${SELINUXTYPE}" = %1 -a -f ${FILE_CONTEXT} ]; then \
        [ -f ${FILE_CONTEXT}.pre ] || cp -f ${FILE_CONTEXT} ${FILE_CONTEXT}.pre; \
     fi; \
     touch %{_sysconfdir}/selinux/%1/.rebuild; \
     if [ -e %{_sysconfdir}/selinux/%1/.policy.sha512 ]; then \
        POLICY_FILE=`ls %{_sysconfdir}/selinux/%1/policy/policy.* | sort | head -1` \
        sha512=`sha512sum $POLICY_FILE | cut -d ' ' -f 1`; \
        checksha512=`cat %{_sysconfdir}/selinux/%1/.policy.sha512`; \
        if [ "$sha512" == "$checksha512" ] ; then \
                rm %{_sysconfdir}/selinux/%1/.rebuild; \
        fi; \
   fi; \
fi;

%define postInstall() \
. %{_sysconfdir}/selinux/config; \
if [ -e %{_sysconfdir}/selinux/%2/.rebuild ]; then \
  rm %{_sysconfdir}/selinux/%2/.rebuild; \
  /usr/sbin/semodule -B -n -s %2; \
fi; \
if [ -n "${TRANSACTIONAL_UPDATE}" ]; then \
  touch /etc/selinux/.autorelabel \
else    \
  if [ "${SELINUXTYPE}" = "%2" ]; then \
    if selinuxenabled; then \
      load_policy; \
    else \
      # probably a first install of the policy \
      true; \
    fi; \
  fi; \
  if selinuxenabled; then \
    if [ %1 -eq 1 ]; then \
      /sbin/restorecon -R /root /var/log /run /etc/passwd* /etc/group* /etc/*shadow* 2> /dev/null; \
    else \
      %relabel %2 \
    fi; \
  else \
    # run fixfiles on next boot \
    touch /.autorelabel \
  fi; \
fi;

%define modulesList() \
awk '$1 !~ "/^#/" && $2 == "=" && $3 == "module" { printf "%%s ", $1 }' ./policy/modules-base.conf > %{buildroot}%{_datadir}/selinux/%1/modules-base.lst \
awk '$1 !~ "/^#/" && $2 == "=" && $3 == "base" { printf "%%s ", $1 }' ./policy/modules-base.conf > %{buildroot}%{_datadir}/selinux/%1/base.lst \
if [ -e ./policy/modules-contrib.conf ];then \
        awk '$1 !~ "/^#/" && $2 == "=" && $3 == "module" { printf "%%s ", $1 }' ./policy/modules-contrib.conf > %{buildroot}%{_datadir}/selinux/%1/modules-contrib.lst; \
fi;

%define nonBaseModulesList() \
contrib_modules=`cat %{buildroot}%{_datadir}/selinux/%1/modules-contrib.lst` \
base_modules=`cat %{buildroot}%{_datadir}/selinux/%1/modules-base.lst` \
for i in $contrib_modules $base_modules; do \
    if [ $i != "sandbox" ];then \
        echo "%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/active/modules/100/$i" >> %{buildroot}%{_datadir}/selinux/%1/nonbasemodules.lst \
    fi; \
done;

%description
SELinux Reference Policy. A complete SELinux policy that can be used
as the system policy for a variety of systems and used as the basis for
creating other policies.

%files
%defattr(-,root,root,-)
%doc COPYING
%dir %{_datadir}/selinux
%dir %{_datadir}/selinux/packages
%dir %{_sysconfdir}/selinux
%ghost %config(noreplace) %{_sysconfdir}/selinux/config
%{_tmpfilesdir}/selinux-policy.conf
%{_rpmconfigdir}/macros.d/macros.selinux-policy

%package sandbox
Summary:        SELinux policy sandbox
Group:          System/Management
Requires(pre):  selinux-policy-targeted = %{version}-%{release}

%description sandbox
SELinux sandbox policy used for the policycoreutils-sandbox package

%files sandbox
%verify(not md5 size mtime) %{_datadir}/selinux/packages/sandbox.pp

%post sandbox
rm -f %{_sysconfdir}/selinux/*/modules/active/modules/sandbox.pp.disabled 2>/dev/null
rm -f %{_sharedstatedir}/selinux/*/active/modules/disabled/sandbox 2>/dev/null
%{_sbindir}/semodule -n -X 100 -i %{_datadir}/selinux/packages/sandbox.pp
if %{_sbindir}/selinuxenabled ; then
    %{_sbindir}/load_policy
fi;
exit 0

%preun sandbox
if [ $1 -eq 0 ] ; then
    %{_sbindir}/semodule -n -d sandbox 2>/dev/null
    if %{_sbindir}/selinuxenabled ; then
        %{_sbindir}/load_policy
    fi;
fi;
exit 0

%prep
%autosetup -n fedora-policy-%{version} -p1
find . -type f -exec sed -i -e "s/distro_suse/distro_redhat/" \{\} \;

%build

%install
mkdir -p %{buildroot}%{_sysconfdir}/selinux
touch %{buildroot}%{_sysconfdir}/selinux/config
mkdir -p %{buildroot}%{_tmpfilesdir}
cp %{SOURCE60} %{buildroot}%{_tmpfilesdir}

# Adjust and install RPM macro file
mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -m 644 %{SOURCE95} %{buildroot}%{_rpmconfigdir}/macros.d/
sed -i 's|SELINUXPOLICYVERSION|%{version}-%{release}|' %{buildroot}%{_rpmconfigdir}/macros.d/macros.selinux-policy
sed -i 's|SELINUXSTOREPATH|%{_sharedstatedir}/selinux|' %{buildroot}%{_rpmconfigdir}/macros.d/macros.selinux-policy

# Always create policy module package directories
mkdir -p %{buildroot}%{_datadir}/selinux/{targeted,mls,minimum,modules}/
mkdir -p %{buildroot}%{_sharedstatedir}/selinux/{targeted,mls,minimum,modules}/

mkdir -p %{buildroot}%{_datadir}/selinux/packages/{targeted,mls,minimum,modules}/

mkdir selinux_config
for i in %{SOURCE10} %{SOURCE11} %{SOURCE12} %{SOURCE13} %{SOURCE14} %{SOURCE15} %{SOURCE20} %{SOURCE21} %{SOURCE22} %{SOURCE30} %{SOURCE31} %{SOURCE32} %{SOURCE40} %{SOURCE41} %{SOURCE42} %{SOURCE50} %{SOURCE51} %{SOURCE52} %{SOURCE91} %{SOURCE92} %{SOURCE94};do
 cp $i selinux_config
done

for i in %{SOURCE120} %{SOURCE121} %{SOURCE122} %{SOURCE123} %{SOURCE124} %{SOURCE125} %{SOURCE126} %{SOURCE127} %{SOURCE128} %{SOURCE129} %{SOURCE130} %{SOURCE131}; do
 cp $i policy/modules/contrib
done

make clean
%if %{BUILD_TARGETED}
%makeCmds targeted mcs allow
%makeModulesConf targeted base contrib
%installCmds targeted mcs allow
# recreate sandbox.pp
rm -rf %{buildroot}%{_sharedstatedir}/selinux/targeted/active/modules/100/sandbox
%make_build %common_params UNK_PERMS=allow NAME=targeted TYPE=mcs sandbox.pp
mv sandbox.pp %{buildroot}%{_datadir}/selinux/packages/sandbox.pp
%modulesList targeted
%nonBaseModulesList targeted
%endif

%if %{BUILD_MINIMUM}
%makeCmds minimum mcs allow
%makeModulesConf targeted base contrib
%installCmds minimum mcs allow
install -m0644 %{SOURCE18} %{buildroot}%{_datadir}/selinux/minimum/modules-minimum-disable.lst
# Sandbox is only targeted
rm -f %{buildroot}%{_sysconfdir}/selinux/minimum/modules/active/modules/sandbox.pp
rm -rf %{buildroot}%{_sharedstatedir}/selinux/minimum/active/modules/100/sandbox
%modulesList minimum
%nonBaseModulesList minimum
%endif

%if %{BUILD_MLS}
%makeCmds mls mls deny
%makeModulesConf mls base contrib
%installCmds mls mls deny
%modulesList mls
%nonBaseModulesList mls
%endif

# Install devel
mkdir -p %{buildroot}%{_mandir}
cp -R  man/* %{buildroot}%{_mandir}
make %common_params UNK_PERMS=allow NAME=targeted TYPE=mcs DESTDIR=%{buildroot} PKGNAME=%{name} install-docs
make %common_params UNK_PERMS=allow NAME=targeted TYPE=mcs DESTDIR=%{buildroot} PKGNAME=%{name} install-headers
mkdir %{buildroot}%{_datadir}/selinux/devel/
mv %{buildroot}%{_datadir}/selinux/targeted/include %{buildroot}%{_datadir}/selinux/devel/include
install -m 644 selinux_config/Makefile.devel %{buildroot}%{_datadir}/selinux/devel/Makefile
install -m 644 doc/example.* %{buildroot}%{_datadir}/selinux/devel/
install -m 644 doc/policy.* %{buildroot}%{_datadir}/selinux/devel/
%{_bindir}/sepolicy manpage -a -p %{buildroot}%{_datadir}/man/man8/ -w -r %{buildroot}
mkdir %{buildroot}%{_datadir}/selinux/devel/html
mv %{buildroot}%{_datadir}/man/man8/*.html %{buildroot}%{_datadir}/selinux/devel/html
mv %{buildroot}%{_datadir}/man/man8/style.css %{buildroot}%{_datadir}/selinux/devel/html
rm %{buildroot}%{_mandir}/man8/container_selinux.8*
rm %{buildroot}%{_datadir}/selinux/devel/include/services/container.if

%post
if [ ! -s %{_sysconfdir}/selinux/config ]; then
    # new install, use old sysconfig file if that exists,
    # else create new one.
    if [ -f  %{_sysconfdir}/sysconfig/selinux-policy ]; then
	mv %{_sysconfdir}/sysconfig/selinux-policy %{_sysconfdir}/selinux/config
    else
	echo "
# This file controls the state of SELinux on the system.
# SELinux can be completly disabled with the \"selinux=0\" kernel
# commandline option.
#
# SELINUX= can take one of these three values:
#     enforcing - SELinux security policy is enforced.
#     permissive - SELinux prints warnings instead of enforcing.
SELINUX=permissive
# SELINUXTYPE= can take one of these three values:
#     targeted - Targeted processes are protected,
#     minimum - Modification of targeted policy. Only selected processes are protected.
#     mls - Multi Level Security protection.
SELINUXTYPE=targeted

" > %{_sysconfdir}/selinux/config
    fi
    ln -sf ../selinux/config %{_sysconfdir}/sysconfig/selinux-policy
    %{_sbindir}/restorecon %{_sysconfdir}/selinux/config 2> /dev/null || :
fi
%tmpfiles_create %_tmpfilesdir/selinux-policy.conf
if [ $1 -eq 1 ]; then
  pam-config -a --selinux
fi
exit 0

%define post_un() \
# disable selinux if we uninstall a policy and it's the used one \
if [ $1 -eq 0 ]; then \
  if [ -s %{_sysconfdir}/selinux/config ]; then \
      source %{_sysconfdir}/selinux/config &> /dev/null || true \
  fi \
  if [ "$SELINUXTYPE" = "$2" ]; then \
    %{_sbindir}/setenforce 0 2> /dev/null \
    if [ -s %{_sysconfdir}/selinux/config ]; then \
      sed -i 's/^SELINUX=.*/SELINUX=permissive/g' %{_sysconfdir}/selinux/config \
    fi \
  fi \
  pam-config -d --selinux \
fi \
exit 0

%postun
if [ $1 = 0 ]; then
     %{_sbindir}/setenforce 0 2> /dev/null
     if [ -s %{_sysconfdir}/selinux/config ]; then
          sed -i 's/^SELINUX=.*/SELINUX=permissive/g' %{_sysconfdir}/selinux/config
     fi
fi
exit 0

%package devel
Summary:        SELinux policy devel
Group:          System/Management
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       /usr/bin/make
Requires:       checkpolicy >= %{CHECKPOLICYVER}
Requires:       m4

%description devel
SELinux policy development and man page package

%files devel
%defattr(-,root,root,-)
%doc %{_datadir}/man/ru/man8/*
%doc %{_datadir}/man/man8/*
%dir %{_datadir}/selinux/devel
%dir %{_datadir}/selinux/devel/html/
%doc %{_datadir}/selinux/devel/html/*
%dir %{_datadir}/selinux/devel/include
%{_datadir}/selinux/devel/include/*
%{_datadir}/selinux/devel/Makefile
%{_datadir}/selinux/devel/example.*

%package doc
Summary:        SELinux policy documentation
Group:          System/Management
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       /usr/bin/xdg-open

%description doc
SELinux policy documentation package

%files doc
%defattr(-,root,root,-)
%doc %{_datadir}/doc/%{name}
%{_datadir}/selinux/devel/policy.*

%if %{BUILD_TARGETED}
%package targeted
Summary:        SELinux targeted base policy
Group:          System/Management
Provides:       selinux-policy-base = %{version}-%{release}
Requires(pre):  coreutils
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       selinux-policy = %{version}-%{release}

%description targeted
SELinux Reference policy targeted base module.

%pre targeted
%preInstall targeted

%post targeted
%postInstall $1 targeted
exit 0

%postun targeted
%post_un $1 targeted

%files targeted -f %{buildroot}%{_datadir}/selinux/targeted/nonbasemodules.lst
%config(noreplace) %{_sysconfdir}/selinux/targeted/contexts/users/unconfined_u
%config(noreplace) %{_sysconfdir}/selinux/targeted/contexts/users/sysadm_u
%fileList targeted
%endif

%if %{BUILD_MINIMUM}
%package minimum
Summary:        SELinux minimum base policy
Group:          System/Management
Provides:       selinux-policy-base = %{version}-%{release}
Requires(post): policycoreutils >= %{POLICYCOREUTILSVER}
Requires(post): policycoreutils-python-utils >= %{POLICYCOREUTILSVER}
Requires(pre):  coreutils
Requires(pre):  /usr/bin/awk
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       selinux-policy = %{version}-%{release}

%description minimum
SELinux Reference policy minimum base module.

%pre minimum
%preInstall minimum
if [ $1 -ne 1 ]; then
    %{_sbindir}/semodule -s minimum --list-modules=full | awk '{ if ($4 != "disabled") print $2; }' > %{_datadir}/selinux/minimum/instmodules.lst
fi

%post minimum
contribpackages=`cat %{_datadir}/selinux/minimum/modules-contrib.lst`
basepackages=`cat %{_datadir}/selinux/minimum/modules-base.lst`
mkdir -p %{_sharedstatedir}/selinux/minimum/active/modules/disabled 2>/dev/null
if [ $1 -eq 1 ]; then
    for p in $contribpackages; do
	touch %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
    done
    for p in $basepackages snapper dbus kerberos nscd rpm rtkit; do
	rm -f %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
    done
    %{_sbindir}/semanage import -S minimum -f - << __eof
login -m  -s unconfined_u -r s0-s0:c0.c1023 __default__
login -m  -s unconfined_u -r s0-s0:c0.c1023 root
__eof
    /sbin/restorecon -R /root /var/log /var/run 2> /dev/null
    %{_sbindir}/semodule -B -s minimum
else
    instpackages=`cat %{_datadir}/selinux/minimum/instmodules.lst`
    for p in $contribpackages; do
	touch %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
    done
    for p in $instpackages snapper dbus kerberos nscd rtkit; do
	rm -f %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
    done
    %{_sbindir}/semodule -B -s minimum
    %relabel minimum
fi
exit 0

%postun minimum
%post_un $1 minimum

%files minimum -f %{buildroot}%{_datadir}/selinux/minimum/nonbasemodules.lst
%config(noreplace) %{_sysconfdir}/selinux/minimum/contexts/users/unconfined_u
%config(noreplace) %{_sysconfdir}/selinux/minimum/contexts/users/sysadm_u
%{_datadir}/selinux/minimum/modules-minimum-disable.lst
%fileList minimum
%endif

%if %{BUILD_MLS}
%package mls
Summary:        SELinux mls base policy
Group:          System/Management
Provides:       selinux-policy-base = %{version}-%{release}
Requires:       policycoreutils-newrole >= %{POLICYCOREUTILSVER}
Requires:       setransd
Requires(pre):  policycoreutils >= %{POLICYCOREUTILSVER}
Requires(pre):  coreutils
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       selinux-policy = %{version}-%{release}

%description mls
SELinux Reference policy mls base module.

%pre mls
%preInstall mls

%post mls
%postInstall $1 mls

%postun mls
%post_un $1 mls

%files mls -f %{buildroot}%{_datadir}/selinux/mls/nonbasemodules.lst
%config(noreplace) %{_sysconfdir}/selinux/mls/contexts/users/unconfined_u
%fileList mls
%endif

%changelog
* Fri Jul 29 2022 zkubala@suse.cz
- Add fix_cloudform.patch to fix cloud-init runcmd issue with snapper
  (bnc#1201015)
* Tue May  3 2022 jsegitz@suse.com
- Add systemd_domain_dyntrans_type.patch to allow systemd to dyntransition.
  This happens in certain boot conditions (bsc#1182500)
* Mon Feb 21 2022 jsegitz@suse.com
- Added fix_hypervkvp.patch to fix issues with hyperv labeling
  (bsc#1193987)
* Tue Oct  5 2021 jsegitz@suse.com
- Add init_watch_unallocated_ttys.patch to fix services with
  StandardOutput=tty (bsc#1187313)
* Thu Sep 30 2021 jsegitz@suse.com
- Fix auditd service start with systemd hardening directives (bsc#1190918)
  * add fix_auditd.patch
* Fri Aug 27 2021 ales.kedroutek@suse.com
- fix rebootmgr does not trigger the reboot properly (boo#1189878)
  * fix managing /etc/rebootmgr.conf
  * allow rebootmgr_t to cope with systemd and dbus messaging
* Thu Aug 26 2021 jsegitz@suse.com
- Properly label cockpit files
- Allow wicked to communicate with network manager on DBUS (bsc#1188331)
* Mon Aug 23 2021 ales.kedroutek@suse.com
- Added policy module for rebootmgr (jsc#SMO-28)
* Tue Aug 17 2021 lnussel@suse.de
- Allow systemd-sysctl to read kernel specific sysctl.conf
  (fix_kernel_sysctl.patch, boo#1184804)
* Tue Aug 10 2021 lnussel@suse.de
- Fix quoting in postInstall macro
* Fri Jul 16 2021 jsegitz@suse.com
- Update to version 20210716
- Remove interfaces for container module before building the package
  (bsc#1188184)
- Updated
  * fix_init.patch
  * fix_systemd_watch.patch
  to adapt to upstream changes
* Thu Jul 15 2021 gmbr3@opensuse.org
- Use tabrmd SELinux modules from tpm2.0-abrmd instead of storing
  here
* Tue Jul  6 2021 aplanas@suse.com
- Add tabrmd SELinux modules from upstream (bsc#1187925)
  https://github.com/tpm2-software/tpm2-abrmd/tree/master/selinux
- Automatic spec-cleaner to fix ordering and misaligned spaces
* Mon Jun 28 2021 jsegitz@suse.com
- Update to version 20210419
- Dropped fix_gift.patch, module was removed
- Updated wicked.te to removed dropped interface
- Refreshed:
  * fix_cockpit.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_logging.patch
  * fix_logrotate.patch
  * fix_networkmanager.patch
  * fix_nscd.patch
  * fix_rpm.patch
  * fix_selinuxutil.patch
  * fix_systemd.patch
  * fix_systemd_watch.patch
  * fix_thunderbird.patch
  * fix_unconfined.patch
  * fix_unconfineduser.patch
  * fix_unprivuser.patch
  * fix_xserver.patch
* Tue May 18 2021 lnussel@suse.de
- allow systemd to watch /usr, /usr/lib, /etc, /etc/pki as we have path units
  that trigger on changes in those.
  Added fix_systemd_watch.patch
- own /usr/share/selinux/packages/$SELINUXTYPE/ and
  /var/lib/selinux/$SELINUXTYPE/active/modules/* to allow packages to install
  files there
* Wed Apr 28 2021 lnussel@suse.de
- allow cockpit socket to bind nodes (fix_cockpit.patch)
- use %%autosetup to get rid of endless patch lines
* Tue Apr 27 2021 jsegitz@suse.com
- Updated fix_networkmanager.patch to allow NetworkManager to watch
  its configuration directories
- Added fix_dovecot.patch to fix dovecot authentication (bsc#1182207)
* Mon Apr 26 2021 jsegitz@suse.com
- Added Recommends for selinux-autorelabel (bsc#1181837)
- Prevent libreoffice fonts from changing types on every relabel
  (bsc#1185265). Added fix_libraries.patch
* Fri Apr 23 2021 jsegitz@suse.com
- Transition unconfined users to ldconfig type (bsc#1183121).
  Extended fix_unconfineduser.patch
* Mon Apr 19 2021 jsegitz@suse.com
- Update to version 20210419
- Refreshed:
  * fix_dbus.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_unprivuser.patch
* Fri Mar 12 2021 ales.kedroutek@suse.com
- Adjust fix_init.patch to allow systemd to do sd-listen on
  tcp socket [bsc#1183177]
* Tue Mar  9 2021 jsegitz@suse.com
- Update to version 20210309
- Refreshed
  * fix_systemd.patch
  * fix_selinuxutil.patch
  * fix_iptables.patch
  * fix_init.patch
  * fix_logging.patch
  * fix_nscd.patch
  * fix_hadoop.patch
  * fix_unconfineduser.patch
  * fix_chronyd.patch
  * fix_networkmanager.patch
  * fix_cron.patch
  * fix_usermanage.patch
  * fix_unprivuser.patch
  * fix_rpm.patch
- Ensure that /usr/etc is labeled according to /etc rules
* Tue Feb 23 2021 kukuk@suse.com
- Update to version 20210223
- Change name of tar file to a more common schema to allow
  parallel installation of several source versions
- Adjust fix_init.patch
* Mon Jan 11 2021 kukuk@suse.com
- Update to version 20210111
  - Drop fix_policykit.patch (integrated upstream)
  - Adjust fix_iptables.patch
  - update container policy
* Tue Nov 10 2020 jsegitz@suse.com
- Updated fix_corecommand.patch to set correct types for the OBS
  build tools
* Thu Oct 29 2020 kukuk@suse.com
- wicked.fc: add libexec directories
- Update to version 20201029
  - update container policy
* Fri Oct 16 2020 kukuk@suse.com
- Update to version 20201016
- Use python3 to build (fc_sort.c was replaced by fc_sort.py which
  uses python3)
- Drop SELINUX=disabled, "selinux=0" kernel commandline option has
  to be used instead. New default is "permissive" [bsc#1176923].
* Thu Sep 10 2020 jsegitz@suse.com
- Update to version 20200910. Refreshed
  * fix_authlogin.patch
  * fix_nagios.patch
  * fix_systemd.patch
  * fix_usermanage.patch
- Delete suse_specific.patch, moved content into fix_selinuxutil.patch
- Cleanup of booleans-* presets
  * Enabled
    user_rw_noexattrfile
    unconfined_chrome_sandbox_transition
    unconfined_mozilla_plugin_transition
    for the minimal policy
  * Disabled
    xserver_object_manager
    for the MLS policy
  * Disabled
    openvpn_enable_homedirs
    privoxy_connect_any
    selinuxuser_direct_dri_enabled
    selinuxuser_ping (aka user_ping)
    squid_connect_any
    telepathy_tcp_connect_generic_network_ports
    for the targeted policy
  Change your local config if you need them
- Build HTML version of manpages for the -devel package
* Thu Sep  3 2020 jsegitz@suse.com
- Drop BuildRequires for python, python-xml. It's not needed anymore
* Tue Sep  1 2020 jsegitz@suse.com
- Drop fix_dbus.patch_orig, was included by accident
- Drop segenxml_interpreter.patch, not used anymore
* Tue Aug 11 2020 kukuk@suse.com
- macros.selinux-policy: move rpm-state directory to /run and
  make sure it exists
* Wed Aug  5 2020 kukuk@suse.com
- Cleanup spec file and follow more closely Fedora
- Label /sys/kernel/uevent_helper with tmpfiles.d/selinux-policy.conf
- Move config to /etc/selinux/config and create during %%post install
  to be compatible with upstream and documentation.
- Add RPM macros for SELinux (macros.selinux-policy)
- Install booleans.subs_dist
- Remove unused macros
- Sync make/install macros with Fedora spec file
- Introduce sandbox sub-package
* Wed Jul 29 2020 kukuk@suse.com
- Add policycoreutils-devel as BuildRequires
* Fri Jul 17 2020 jsegitz@suse.com
- Update to version 20200717. Refreshed
  * fix_fwupd.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_irqbalance.patch
  * fix_logrotate.patch
  * fix_nagios.patch
  * fix_networkmanager.patch
  * fix_postfix.patch
  * fix_sysnetwork.patch
  * fix_systemd.patch
  * fix_thunderbird.patch
  * fix_unconfined.patch
  * fix_unprivuser.patch
  * selinux-policy.spec
- Added update.sh to make updating easier
* Tue Jul 14 2020 jsegitz@suse.com
- Updated fix_unconfineduser.patch to allow unconfined_dbusd_t access
  to accountsd dbus
- New patch:
  * fix_nis.patch
- Updated patches:
  * fix_postfix.patch: Transition is done in distribution specific script
* Tue Jun  2 2020 jsegitz@suse.de
- Added module for wicked
- New patches:
  * fix_authlogin.patch
  * fix_screen.patch
  * fix_unprivuser.patch
  * fix_rpm.patch
  * fix_apache.patch
* Thu Mar 26 2020 jsegitz@suse.de
- Added module for rtorrent
- Enable snapper module in minimum policy to reduce issues on BTRFS
  Updated fix_snapper.patch to prevent relabling of snapshot
* Mon Mar  9 2020 jsegitz@suse.de
- New patches:
  * fix_accountsd.patch
  * fix_automount.patch
  * fix_colord.patch
  * fix_mcelog.patch
  * fix_sslh.patch
  * fix_nagios.patch
  * fix_openvpn.patch
  * fix_cron.patch
  * fix_usermanage.patch
  * fix_smartmon.patch
  * fix_geoclue.patch
  * suse_specific.patch
  Default systems should now work without selinuxuser_execmod
- Removed xdm_entrypoint_pam.patch, necessary change is in
  fix_unconfineduser.patch
- Enable SUSE specific settings again
* Wed Feb 19 2020 jsegitz@suse.de
- Update to version 20200219
  Refreshed fix_hadoop.patch
  Updated
  * fix_dbus.patch
  * fix_hadoop.patch
  * fix_nscd.patch
  * fix_xserver.patch
  Renamed postfix_paths.patch to fix_postfix.patch
  Added
  * fix_init.patch
  * fix_locallogin.patch
  * fix_policykit.patch
  * fix_iptables.patch
  * fix_irqbalance.patch
  * fix_ntp.patch
  * fix_fwupd.patch
  * fix_firewalld.patch
  * fix_logrotate.patch
  * fix_selinuxutil.patch
  * fix_corecommand.patch
  * fix_snapper.patch
  * fix_systemd.patch
  * fix_unconfined.patch
  * fix_unconfineduser.patch
  * fix_chronyd.patch
  * fix_networkmanager.patch
  * xdm_entrypoint_pam.patch
- Removed modules minimum_temp_fixes and targeted_temp_fixes
  from the corresponding policies
- Reduced default module list of minimum policy by removing
  apache inetd nis postfix mta modules
- Adding/removing necessary pam config automatically
- Minimum and targeted policy: Enable domain_can_mmap_files by default
- Targeted policy: Disable selinuxuser_execmem, selinuxuser_execmod and
  selinuxuser_execstack to have safe defaults
* Fri Aug  9 2019 jsegitz@suse.de
- Moved back to fedora policy (20190802)
- Removed spec file conditionals for old SELinux userland
- Removed config.tgz
- Removed patches:
  * label_sysconfig.selinux.patch
  * label_var_run_rsyslog.patch
  * suse_additions_obs.patch
  * suse_additions_sslh.patch
  * suse_modifications_apache.patch
  * suse_modifications_cron.patch
  * suse_modifications_getty.patch
  * suse_modifications_logging.patch
  * suse_modifications_ntp.patch
  * suse_modifications_usermanage.patch
  * suse_modifications_virt.patch
  * suse_modifications_xserver.patch
  * sysconfig_network_scripts.patch
  * segenxml_interpreter.patch
- Added patches:
  * fix_djbdns.patch
  * fix_dbus.patch
  * fix_gift.patch
  * fix_java.patch
  * fix_hadoop.patch
  * fix_thunderbird.patch
  * postfix_paths.patch
  * fix_nscd.patch
  * fix_sysnetwork.patch
  * fix_logging.patch
  * fix_xserver.patch
  * fix_miscfiles.patch
  to fix problems with the coresponding modules
- Added sedoctool.patch to prevent build failures
- This also adds three modules:
  * packagekit.(te|if|fc)
    Basic (currently permissive) module for packagekit
  * minimum_temp_fixes.(te|if|fc)
    and
  * targeted_temp_fixes.(te|if|fc)
    both are currently necessary to get the systems to boot in
    enforcing mode. Most of them obviosly stem from mislabeled
    files, so this needs to be worked through and then removed
    eventually
  Also selinuxuser_execstack, selinuxuser_execmod and
  domain_can_mmap_files need to be enabled. Especially the first
  two are bad and should be removed ASAP
* Thu Jul 11 2019 jsegitz@suse.com
- Update to refpolicy 20190609. New modules for stubby and several
  systemd updates, including initial support for systemd --user
  sessions.
  Refreshed
  * label_var_run_rsyslog.patch
  * suse_modifications_cron.patch
  * suse_modifications_logging.patch
  * suse_modifications_ntp.patch
  * suse_modifications_usermanage.patch
  * suse_modifications_xserver.patch
  * sysconfig_network_scripts.patch
* Mon Feb  4 2019 jsegitz@suse.com
- Update to refpolicy 20190201. New modules for chromium, hostapd,
  and sigrok and minor fixes for existing modules.
  Refreshed suse_modifications_usermanage.patch
* Wed Nov 28 2018 jsegitz@suse.com
- Change default state to disabled and disable SELinux after
  uninstallation of policy to prevent unbootable system
  (bsc#1108949, bsc#1109590)
* Tue Nov 27 2018 jsegitz@suse.com
- Use refpolicy 20180701 as a base
- Dropped patches
  * allow-local_login_t-read-shadow.patch
  * dont_use_xmllint_in_make_conf.patch
  * label_sysconfig.selinux-policy.patch
  * policy-rawhide-base.patch
  * policy-rawhide-contrib.patch
  * suse_modifications_authlogin.patch
  * suse_modifications_dbus.patch
  * suse_modifications_glusterfs.patch
  * suse_modifications_ipsec.patch
  * suse_modifications_passenger.patch
  * suse_modifications_policykit.patch
  * suse_modifications_postfix.patch
  * suse_modifications_rtkit.patch
  * suse_modifications_selinuxutil.patch
  * suse_modifications_ssh.patch
  * suse_modifications_staff.patch
  * suse_modifications_stapserver.patch
  * suse_modifications_systemd.patch
  * suse_modifications_unconfined.patch
  * suse_modifications_unconfineduser.patch
  * suse_modifications_unprivuser.patch
  * systemd-tmpfiles.patch
  * type_transition_contrib.patch
  * type_transition_file_class.patch
  * useradd-netlink_selinux_socket.patch
  * xconsole.patch
  Rebased the other patches to apply to refpolicy
- Added segenxml_interpreter.patch to not use env in shebang
- Added rpmlintrc to surpress duplicate file warnings
* Mon Mar 26 2018 rgoldwyn@suse.com
- Add overlayfs as xattr capable (bsc#1073741)
  * add-overlayfs-as-xattr-capable.patch
* Tue Dec 12 2017 jsegitz@suse.com
- Added
  * suse_modifications_glusterfs.patch
  * suse_modifications_passenger.patch
  * suse_modifications_stapserver.patch
  to modify module name to make the current tools happy
* Wed Nov 29 2017 rbrown@suse.com
- Repair erroneous changes introduced with %%_fillupdir macro
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar 15 2017 mwilck@suse.com
- POLCYVER depends both on the libsemanage/policycoreutils version
  and the kernel. The former is more important for us, kernel seems
  to have all necessary features in Leap 42.1 already.
- Replaced = runtime dependencies on checkpolicy/policycoreutils
  with "=". 2.5 policy is not supposed to work with 2.3 tools,
  The runtime policy tools need to be same the policy was built with.
* Wed Mar 15 2017 mwilck@suse.com
- Changes required by policycoreutils update to 2.5
  * lots of spec file content needs to be conditional on
    policycoreutils version.
- Specific policycoreutils 2.5 related changes:
  * modules moved from /etc/selinux to /var/lib/selinux
  (https://github.com/SELinuxProject/selinux/wiki/Policy-Store-Migration)
  * module path now includes includes priority. Users override default
  policies by setting higher priority. Thus installed policy modules can be
  fully verified by RPM.
  * Installed modules have a different format and path.
  Raw bzip2 doesn't suffice to create them any more, but we can process them
  all in a single semodule -i command.
- Policy version depends on kernel / distro version
  * do not touch policy.<version>, rather fail if it's not created
- Enabled building mls policy for Leap (not for SLES)
- Other
  * Bug: "sandbox.disabled" should be "sandbox.pp.disabled" for old policycoreutils
  * Bug: (minimum) additional modules that need to be activated: postfix
  (required by apache), plymouthd (required by getty)
  * Cleanup: /etc -> %%{sysconfdir} etc.
* Thu Aug 13 2015 jsegitz@novell.com
- fixed missing role assignment in cron_unconfined_role
* Tue Aug 11 2015 jsegitz@novell.com
- Updated suse_modifications_ipsec.patch, removed dontaudits for
  ipsec_mgmt_t and granted matching permissions
* Wed Aug  5 2015 jsegitz@novell.com
- Added suse_modifications_ipsec.patch to grant additional privileges
  to ipsec_mgmt_t
* Tue Jul 21 2015 jsegitz@novell.com
- Minor changes for CC evaluation. Allow reading of /dev/random
  and ipc_lock for dbus and dhcp
* Wed Jun 24 2015 jsegitz@novell.com
- Transition from unconfined user to cron admin type
- Allow systemd_timedated_t to talk to unconfined dbus for minimal
  policy (bsc#932826)
- Allow hostnamectl to set the hostname (bsc#933764)
* Wed May 20 2015 jsegitz@novell.com
- Removed ability of staff_t and user_t to use svirt. Will reenable
  this later on with a policy upgrade
  Added suse_modifications_staff.patch
* Wed Feb 25 2015 jsegitz@novell.com
- Added dont_use_xmllint_in_make_conf.patch to remove xmllint usage
  in make conf. This currently breaks manual builds.
- Added BuildRequires for libxml2-tools to enable xmllint checks
  once the issue mentioned above is solved
* Thu Jan 29 2015 jsegitz@novell.com
- adjusted suse_modifications_ntp to match SUSE chroot paths
* Wed Jan 28 2015 jsegitz@novell.com
- Added
  * suse_additions_obs.patch to allow local builds by OBS
  * suse_additions_sslh.patch to confine sslh
- Added suse_modifications_cron.patch to adjust crontabs contexts
- Modified suse_modifications_postfix.patch to match SUSE paths
- Modified suse_modifications_ssh.patch to bring boolean
  sshd_forward_ports back
- Modified
  * suse_modifications_dbus.patch
  * suse_modifications_unprivuser.patch
  * suse_modifications_xserver.patch
  to allow users to be confined
- Added
  * suse_modifications_apache.patch
  * suse_modifications_ntp.patch
  and modified
  * suse_modifications_xserver.patch
  to fix labels on startup scripts used by systemd
- Removed unused and incorrect interface dev_create_all_dev_nodes
  from systemd-tmpfiles.patch
- Removed BuildRequire for selinux-policy-devel
* Fri Jan 23 2015 jsegitz@novell.com
- Major cleanup of the spec file
* Fri Jan 23 2015 jsegitz@novell.com
- removed suse_minimal_cc.patch and splitted them into
  * suse_modifications_dbus.patch
  * suse_modifications_policykit.patch
  * suse_modifications_postfix.patch
  * suse_modifications_rtkit.patch
  * suse_modifications_unconfined.patch
  * suse_modifications_systemd.patch
  * suse_modifications_unconfineduser.patch
  * suse_modifications_selinuxutil.patch
  * suse_modifications_logging.patch
  * suse_modifications_getty.patch
  * suse_modifications_authlogin.patch
  * suse_modifications_xserver.patch
  * suse_modifications_ssh.patch
  * suse_modifications_usermanage.patch
- Added suse_modifications_virt.patch to enable svirt on s390x
* Sat Nov  8 2014 ledest@gmail.com
- fix bashism in post script
* Thu Sep 18 2014 jsegitz@suse.com
  Redid changes done by vcizek@suse.com in SLE12 package
- disable build of MLS policy
- removed outdated description files
  * Alan_Rouse-openSUSE_with_SELinux.txt
  * Alan_Rouse-Policy_Development_Process.txt
* Mon Sep  8 2014 jsegitz@suse.com
- removed remove_duplicate_filetrans_pattern_rules.patch
* Fri Sep  5 2014 jsegitz@suse.com
- Updated policy to include everything up until 20140730 (refpolicy and
  fedora rawhide improvements). Rebased all patches that are still
  necessary
- Removed permissivedomains.pp. Doesn't work with the new policy
- modified spec file so that all modifications for distro=redhat and
  distro=suse will be used.
- added selinux-policy-rpmlintrc to suppress some warnings that aren't
  valid for this package
- added suse_minimal_cc.patch to create a suse specific module to prevent
  errors while using the minimum policy. Will rework them in the proper
  places once the minimum policy is reworked to really only confine a
  minimal set of domains.
* Tue Sep  2 2014 vcizek@suse.com
- removed source files which were not used
  * modules-minimum.conf, modules-mls.conf, modules-targeted.conf,
    permissivedomains.fc, permissivedomains.if, permissivedomains.te,
    seusers, seusers-mls, seusers-targeted, users_extra-mls,
    users_extra-targeted
* Mon Jun  2 2014 vcizek@suse.com
- remove duplicate filetrans_pattern rules
  * fixes build with libsepol-2.3
  * added remove_duplicate_filetrans_pattern_rules.patch
* Mon Dec  9 2013 vcizek@suse.com
- enable build of mls and targeted policies
- fixes to the minimum policy:
- label /var/run/rsyslog correctly
  * label_var_run_rsyslog.patch
- allow systemd-tmpfiles to create devices
  * systemd-tmpfiles.patch
- add rules for sysconfig
  * correctly label /dev/.sysconfig/network
  * added sysconfig_network_scripts.patch
- run restorecon and fixfiles only if if selinux is enabled
- fix console login
  * allow-local_login_t-read-shadow.patch
- allow rsyslog to write to xconsole
  * xconsole.patch
- useradd needs to call selinux_check_access (via pam_rootok)
  * useradd-netlink_selinux_socket.patch
* Mon Aug 12 2013 ro@suse.de
- fix build on factory: newer rpm does not allow to mark
  non-directories as dir anymore (like symlinks in this case)
* Thu Jul 11 2013 coolo@suse.com
- install COPYING
* Fri Mar 22 2013 vcizek@suse.com
- switch to Fedora as upstream
- added patches:
  * policy-rawhide-base.patch
  * policy-rawhide-contrib.patch
  * type_transition_file_class.patch
  * type_transition_contrib.patch
  * label_sysconfig.selinux-policy.patch
* Tue Dec 11 2012 vcizek@suse.com
- bump up policy version to 27, due to recent libsepol update
- dropped currently unused policy-rawhide.patch
- fix installing of file_contexts (this enables restorecond to run properly)
- Recommends: audit and setools
* Mon Dec 10 2012 meissner@suse.com
- mark included files in source
* Mon Oct 22 2012 vcizek@suse.com
- update to 2.20120725
- added selinux-policy-run_sepolgen_during_build.patch
- renamed patch with SUSE-specific policy to selinux-policy-SUSE.patch
- dropped policygentool and OLPC stuff
* Wed May  9 2012 coolo@suse.com
- patch license to be in spdx.org format
* Fri May 21 2010 prusnak@suse.cz
- use policy created by Alan Rouse
* Sun Apr 11 2010 justinmattock@gmail.com
- Adjust selinux-policy.spec so that the policy
  source tree is put in /usr/share/doc/packages/selinux-*
  so users can build the policy [bnc#582404]
* Wed Apr  7 2010 thomas@novell.com
- fixed fileperms of /etc/selinux/config to be 644 to allow
  libselinux to read from it (bnc#582399)
  this is also the default file mode in fedora 12
* Fri Jun 26 2009 thomas@novell.com
- added config file for /etc/selinux/
* Wed Jan 14 2009 prusnak@suse.cz
- updated to version 2008.12.10
  * Fix consistency of audioentropy and iscsi module naming.
  * Debian file context fix for xen from Russell Coker.
  * Xserver MLS fix from Eamon Walsh.
  * Add omapi port for dhcpcd.
  * Deprecate per-role templates and rolemap support.
  * Implement user-based access control for use as role separations.
  * Move shared library calls from individual modules to the domain module.
  * Enable open permission checks policy capability.
  * Remove hierarchy from portage module as it is not a good example of hieararchy.
  * Remove enableaudit target from modular build as semodule -DB supplants it.
  * Added modules:
  - milter (Paul Howarth)
* Thu Oct 16 2008 prusnak@suse.cz
- updated to version 2008.10.14
  * Debian update for NetworkManager/wpa_supplicant from Martin Orr.
  * Logrotate and Bind updates from Vaclav Ovsik.
  * Init script file and domain support.
  * Glibc 2.7 fix from Vaclav Ovsik.
  * Samba/winbind update from Mike Edenfield.
  * Policy size optimization with a non-security file attribute from James Carter.
  * Database labeled networking update from KaiGai Kohei.
  * Several misc changes from the Fedora policy, cherry picked by David Hardeman.
  * Large whitespace fix from Dominick Grift.
  * Pam_mount fix for local login from Stefan Schulze Frielinghaus.
  * Issuing commands to upstart is over a datagram socket, not the initctl named pipe.
  * Updated init_telinit() to match.
  * Added modules:
  - cyphesis (Dan Walsh)
  - memcached (Dan Walsh)
  - oident (Dominick Grift)
  - w3c (Dan Walsh)
* Tue Jul 22 2008 prusnak@suse.cz
- initial version 2008.07.02 from tresys
